@@ -15,18 +15,21 @@
  */
 
 use crate::errors::*;
-use crate::eval::ModelEvaluator;
+use crate::model_evaluator::ModelEvaluator;
 use dmntk_common::Result;
 use dmntk_feel::context::FeelContext;
 use dmntk_feel::values::Value;
 use dmntk_model::model::*;
 
 /// Evaluates a [Decision] defined by specified name.
-pub fn evaluate_decision_by_name(definitions: &Definitions, name: &str, ctx: &FeelContext) -> Result<Value> {
+pub fn evaluate_decision_by_name(definitions: &Definitions, name: &str, input_data: &FeelContext) -> Result<Value> {
   if let Some(decision) = definitions.decision_by_name(name) {
-    println!("\nAAA:DECISION_NAME = {}", decision.name());
-    let evaluator = ModelEvaluator::new(definitions)?;
-    evaluator.eval_decision(decision, ctx)
+    // println!("AAA: <DECISION_NAME> = {}", decision.name());
+    // println!("AAA: <INPUT_DATA>    = {}", input_data);
+    let id = decision.id().as_ref().ok_or_else(err_empty_identifier)?;
+    let model_evaluator = ModelEvaluator::new(definitions)?;
+    let result = model_evaluator.evaluate_decision(id, input_data);
+    Ok(result)
   } else {
     Err(err_decision_with_name_not_found(name))
   }
